Created by sforskeezy | sforskeezy.com
discord: sforskeezy
github: sforskeezy

This is a simple README file for the project __mformodal__

You can create a modal with this

## Installation
```bash
npm install mformodal
```


